# Script for 'bias-adjusting' RCM results for the CLIPC project
# Rasmus Benestad, MET, Nov 20, 2014
# Adjustments to function etc.: Andreas Dobler, MET, May 2015
# Remove all validations, etc. -> Let's do this externally (AD)

#-----------------------------------------------------------------
# ?set modules with> setmodulesesd

# zoo, ncdf4, esd:  /modules/trusty/R3.1.3-FOU-modules
# qmap, devtools: 

library(zoo,       lib.loc='/modules/trusty/R3.1.3-FOU-modules')
library(ncdf4,     lib.loc='/modules/trusty/R3.1.3-FOU-modules')
library(esd,       lib.loc='/modules/trusty/R3.1.3-FOU-modules')
library(qmap)

clipc_debias_apply_pr <- function(fnapply,fnfit,method="QUANT",fnout){  
  
  print(date())
  # Name of the INPUT file with the application data (biased): fnapply
  # Name of the INPUT file with the fitting (from training)  : fnfit
  # Name of the OUTPUT file with the bias-adjusted results   : fnout
  # Name of the INPUT file with the training data (biased)   : fntrain
  # Name of the INPUT file with the reference data           : fnobs
  # Name of the OUTPUT file with the fitting                 : fnout
  # Methods:
  # QUANT: simple quantile mapping (DEFAULT)
  # QUANT1001: quantile mapping using 1001 quantiles
  
  #===================================================
  # WARNING: THIS OVERWRITES THE FILE FNOUT!!!!
  # Make a copy of the original file with the name of the output file
  # (this keeps the structure and everything)
  system(paste("nccopy",fnapply,fnout,sep=" "))
  
  #===================================================
  # Get some info about the netCDF file to be bias-adjusted
  ncout <- nc_open(fnout,write=TRUE)
  
  d1 <- ncout$dim[['rlon']]$len
  d2 <- ncout$dim[['rlat']]$len
  d3 <- ncout$dim[['time']]$len
  
  #array for debiased values
  Zmat <- array(NA,c(d1,d2,d3))
  
  ## Read the fitting data from file
  ## The file holds a fit list for each longitude in the variable BCL
  load(fnfit)
  
  #===================================
  # Loop over longitudes
  for (i in 1:d1) { 
    print(paste(d1+1-i,"meridians to go..."))#print countdown for i
    
    ## Read the data to be corrected (meridional vector)
    appdata <- ncvar_get(ncout,varid='pr',start=c(i,1,1),count=c(1,-1,-1))
    
    ##----------------------------------------------------------------------    
    ## fit
    if (method=='QUANT' || method=='QUANT1001') {
      ## quantile-quantile mapping (values outside the past range are extrapolated)
      ## Gudmundsson, et al., 2012, 16, 3383-3390, doi:10.5194/hess-16-3383-2012.
      
      Z <- t(doQmap(t(appdata),BCL[[i]]))
    }
    
    ## set missing values
    Z[!is.finite(Z)] <-  1.e20
    
    ##Save in the array for debiased values
    Zmat[i,,] <- Z
  }
  
  #Write to file
  ncvar_put(ncout,varid="pr",Zmat)
  
  nc_close(ncout)  
  print('job finished!')
  print(date())
  
}
