# Script for 'bias-adjusting' RCM results for the CLIPC project
# Rasmus Benestad, MET, Nov 20, 2014
# Adjustments to function etc.: Andreas Dobler, MET, May 2015
# Remove all validations, etc. -> Let's do this externally (AD)

#-----------------------------------------------------------------
# ?set modules with> setmodulesesd

# zoo, ncdf4, esd:  /modules/trusty/R3.1.3-FOU-modules
# qmap, devtools: 

library(zoo,       lib.loc='/modules/trusty/R3.1.3-FOU-modules')
library(ncdf4,     lib.loc='/modules/trusty/R3.1.3-FOU-modules')
library(esd,       lib.loc='/modules/trusty/R3.1.3-FOU-modules')
library(qmap)

clipc_debias_training_tas <- function(fntrain,fnobs,method="QUANTAnom",fnout){  
  
  print(date())
  # Name of the INPUT file with the training data (biased)   : fntrain
  # Name of the INPUT file with the reference data           : fnobs
  # Name of the OUTPUT file with the fitting                 : fnout
  # Methods:
  # QUANT: simple quantile mapping
  # QUANT1001: quantile mapping using 1001 quantiles
  # QUANTAnom: quantile mapping of anomalies (DEFAULT)  
  
  #===================================================
  # Get some info about the netCDF file to be bias-adjusted
  
  nctrain <- nc_open(fntrain)
  ncobs <- nc_open(fnobs)
  
  d1 <- nctrain$dim[['rlon']]$len
  
  #List for bias correction savings
  BCL <- list(d1)
  
  #===================================
  # Loop over longitudes
  for (i in 1:d1) { 
    print(paste(d1+1-i,"meridians to go..."))#print countdown for i
    
    ## Read the training data (meridional vector)
    traindata <- ncvar_get(nctrain,varid='tas',start=c(i,1,1),count=c(1,-1,-1))
    
    ## Read the reference data (meridional vector)
    # This assumes the reference data (obs) are on the same grid as the data to be adjusted
    obs <- ncvar_get(ncobs,varid='tas',start=c(i,1,1),count=c(1,-1,-1))
    
    ##----------------------------------------------------------------------    
    ## fit
    if (method=='QUANT') {
      ## quantile-quantile mapping (values outside the past range are extrapolated)
      ## Gudmundsson, et al., 2012, 16, 3383-3390, doi:10.5194/hess-16-3383-2012.
      BCL[[i]] <- fitQmapQUANT(t(obs),t(traindata),wet.day=FALSE)
    }
    if (method=='QUANT1001') {
      ## quantile-quantile mapping using 1001 quantiles
      ## (values outside the past range are extrapolated)
      
      # Get 1001 quantiles
      obsquant <- apply(obs,1,quantile,probs = seq(0,1,0.001))
      trainquant <- apply(traindata,1,quantile,probs = seq(0,1,0.001))
    
      #fit
      #!!!NO NEED TO TRANSPOSE SINCE apply(..,1,quantile,...) ALREADY TRANSPOSES!!!
      BCL[[i]] <- fitQmapQUANT(obsquant,trainquant,wet.day=FALSE)
    }
    if (method=='QUANTAnom') {
      ## quantile-quantile mapping of anomalies (w.r.t. trainingdata)
      ## (values outside the past range are extrapolated)
      
      # Subtract mean before fit
      obsanom <- obs - rowMeans(traindata)
      trainanom <- traindata - rowMeans(traindata)
      
      #fit
      BCL[[i]] <- fitQmapQUANT(t(obsanom),t(trainanom),wet.day=FALSE)
    }
    ##----------------------------------------------------------------------
  }
  
  nc_close(nctrain)
  nc_close(ncobs)
  
  ## Save the data to file
  save(BCL,file=fnout)
  
  print('job finished!')
  print(date())
  
}
