eval_plot <- function(adjfile,simfile,obsfile){
  
  library(ncdf4)
  library(fields)
  
  RMSE <- function(sim,obs) sqrt(mean((sim - obs)^2, na.rm=TRUE)) 
  
  outfilename <- paste("bias_",simfile,".png",sep="")
  
  nc <- nc_open(adjfile)
  adj <- ncvar_get(nc,"tasAdjust")
  nc_close(nc)
  
  nc <- nc_open(obsfile)
  obs <- ncvar_get(nc,"tas")
  nc_close(nc)
  
  nc <- nc_open(simfile)
  sim <- ncvar_get(nc,"tas")
  nc_close(nc)
  
  simnameparts <- strsplit(simfile,"_")[[1]]
  simname <- paste(simnameparts[6]," driven by ",simnameparts[3],"_",simnameparts[4],"_",simnameparts[5],sep="")
                         
  png(filename = outfilename,width=2000,height=1200,pointsize = 30)
  
  m <- matrix(c(1,2,3,4,5,6,7,8,9,10,11,11,11,11,11),nrow = 3,ncol = 5,byrow = TRUE)
  
  layout(mat = m,heights = c(2.5,2.5,1))
  
  par(mar = c(0.25,0.25,1,0.25))
  
  cols = tim.colors(22)
  rand = c(-26.25,26.25)/2
  lim = 26/2
  
  image(pmax(pmin(apply(sim,c(1,2),mean)-apply(obs,c(1,2),mean),lim),-lim),xlab="",ylab="",xaxt="n",yaxt="n",zlim=rand,col=cols,main="Annual")
  legend("bottomleft",legend=paste("RMSE=",round(RMSE(apply(sim,c(1,2),mean),apply(obs,c(1,2),mean)),2),"K"),cex = 1,bty="n")
  box()
  
  image(pmax(pmin(sim[,,1]-obs[,,1],lim),-lim),xlab="",ylab="",xaxt="n",yaxt="n",zlim=rand,col=cols,main="DJF")
  legend("bottomleft",legend=paste("RMSE=",round(RMSE(sim[,,1],obs[,,1]),2),"K"),cex = 1,bty="n")
  box()
  
  image(pmax(pmin(sim[,,2]-obs[,,2],lim),-lim),xlab="",ylab="",xaxt="n",yaxt="n",zlim=rand,col=cols,main="MAM")
  legend("bottomleft",legend=paste("RMSE=",round(RMSE(sim[,,2],obs[,,2]),2),"K"),cex = 1,bty="n")
  box()
  
  image(pmax(pmin(sim[,,3]-obs[,,3],lim),-lim),xlab="",ylab="",xaxt="n",yaxt="n",zlim=rand,col=cols,main="JJA")
  legend("bottomleft",legend=paste("RMSE=",round(RMSE(sim[,,3],obs[,,3]),2),"K"),cex = 1,bty="n")
  box()
  
  image(pmax(pmin(sim[,,4]-obs[,,4],lim),-lim),xlab="",ylab="",xaxt="n",yaxt="n",zlim=rand,col=cols,main="SON")
  legend("bottomleft",legend=paste("RMSE=",round(RMSE(sim[,,4],obs[,,4]),2),"K"),cex = 1,bty="n")
  box()
  
  par(mar = c(1,0.25,0.25,0.25))
  
  image(pmax(pmin(apply(adj,c(1,2),mean)-apply(obs,c(1,2),mean),lim),-lim),xlab="",ylab="",xaxt="n",yaxt="n",zlim=rand,col=cols)
  legend("bottomleft",legend=paste("RMSE=",round(RMSE(apply(adj,c(1,2),mean),apply(obs,c(1,2),mean)),2),"K"),cex = 1,bty="n")
  box()
  
  image(pmax(pmin(adj[,,1]-obs[,,1],lim),-lim),xlab="",ylab="",xaxt="n",yaxt="n",zlim=rand,col=cols)
  legend("bottomleft",legend=paste("RMSE=",round(RMSE(adj[,,1],obs[,,1]),2),"K"),cex = 1,bty="n")
  box()
  
  image(pmax(pmin(adj[,,2]-obs[,,2],lim),-lim),xlab="",ylab="",xaxt="n",yaxt="n",zlim=rand,col=cols)
  legend("bottomleft",legend=paste("RMSE=",round(RMSE(adj[,,2],obs[,,2]),2),"K"),cex = 1,bty="n")
  box()
  
  image(pmax(pmin(adj[,,3]-obs[,,3],lim),-lim),xlab="",ylab="",xaxt="n",yaxt="n",zlim=rand,col=cols)
  legend("bottomleft",legend=paste("RMSE=",round(RMSE(adj[,,3],obs[,,3]),2),"K"),cex = 1,bty="n")
  box()
  
  image(pmax(pmin(adj[,,4]-obs[,,4],lim),-lim),xlab="",ylab="",xaxt="n",yaxt="n",zlim=rand,col=cols)
  legend("bottomleft",legend=paste("RMSE=",round(RMSE(adj[,,4],obs[,,4]),2),"K"),cex = 1,bty="n")
  box()
  
  par(mar = c(0,0,1,0))
  
  plot(1, type = "n",axes=FALSE, xlab="", ylab="",main="Temperature bias [K] | Top: Raw | Bottom: Bias-corrected (METNO-QMAP-EOBS10-1981-2010)",asp=1)
  par(mar = c(0,0,1,0))
  image.plot(pmax(pmin(adj[,,4]-obs[,,4],lim),-lim),xlab="",ylab="",xaxt="n",yaxt="n",zlim=rand,col=cols,legend.only = TRUE, horizontal = TRUE, legend.mar = 20,legend.width = 4, axis.args=list(at=c(-25,-20,-10,0,10,20,25)/2),legend.lab = simname,legend.line = 3)
  
  dev.off()
  
}
