library(plotrix)
library(ncdf4)
library(fields)

setwd("/lustre/mnt/andreasd/CLIPC/WP6/EUR-44/tas/test")
bc_files <- Sys.glob("CLIPC*monmean*")

adjfile <- bc_files[1]
simfile <- gsub("v1_METNO-QMAP-EOBS10-1981-2010","v1",gsub("CLIPC_tasAdjust","tas",adjfile))
obsfile <- "tas_EUR-44_EOBS10_obs_r1i1p1_ECAD_v1_monmean_seas_19810101-20101231.nc"

nc <- nc_open(adjfile)
adj <- ncvar_get(nc,"tasAdjust")
nc_close(nc)

nc <- nc_open(obsfile)
obs <- ncvar_get(nc,"tas")
nc_close(nc)

nc <- nc_open(simfile)
sim <- ncvar_get(nc,"tas")
nc_close(nc)

png(filename = "taylor_tas.png",width=2400,height=1200,pointsize = 30)


taylor.diagram(subset(as.vector(obs[,,1]),!is.na(obs[,,1])),subset(as.vector(sim[,,1]),!is.na(obs[,,1])),pos.cor=TRUE,normalize=TRUE,main="",col=colours(1)[274],pcex=2,pch="*",ref.sd=TRUE,xlab="Norm. standard deviation",ylab="Norm. standard deviation",mar=c(5,4,2,30))

bclength <- length(bc_files)

legendstrings <- array(NA,bclength)

for (i in 1:bclength)
{
  adjfile <- bc_files[i]
  simfile <- gsub("v1_METNO-QMAP-EOBS10-1981-2010","v1",gsub("CLIPC_tasAdjust","tas",adjfile))
  obsfile <- "tas_EUR-44_EOBS10_obs_r1i1p1_ECAD_v1_monmean_seas_19810101-20101231.nc"
  
  nc <- nc_open(adjfile)
  adj <- ncvar_get(nc,"tasAdjust")
  nc_close(nc)
  
  nc <- nc_open(obsfile)
  obs <- ncvar_get(nc,"tas")
  nc_close(nc)
  
  nc <- nc_open(simfile)
  sim <- ncvar_get(nc,"tas")
  nc_close(nc)
  
  taylor.diagram(subset(as.vector(obs[,,1]),!is.na(obs[,,1])),subset(as.vector(sim[,,1]),!is.na(obs[,,1])),add=TRUE,col=colours(1)[3*i+272],normalize=TRUE,pcex=2,pch="*")
  taylor.diagram(subset(as.vector(obs[,,2]),!is.na(obs[,,2])),subset(as.vector(sim[,,2]),!is.na(obs[,,2])),add=TRUE,col=colours(1)[3*i+272],normalize=TRUE,pcex=2,pch="^")
  taylor.diagram(subset(as.vector(obs[,,3]),!is.na(obs[,,3])),subset(as.vector(sim[,,3]),!is.na(obs[,,3])),add=TRUE,col=colours(1)[3*i+272],normalize=TRUE,pcex=2,pch="~")
  taylor.diagram(subset(as.vector(obs[,,4]),!is.na(obs[,,4])),subset(as.vector(sim[,,4]),!is.na(obs[,,4])),add=TRUE,col=colours(1)[3*i+272],normalize=TRUE,pcex=1.4,pch="v")
  
  taylor.diagram(subset(as.vector(obs[,,1]),!is.na(obs[,,1])),subset(as.vector(adj[,,1]),!is.na(obs[,,1])),add=TRUE,col=colours(1)[3*i+272],normalize=TRUE,pcex=3,pch="*")
  taylor.diagram(subset(as.vector(obs[,,2]),!is.na(obs[,,2])),subset(as.vector(adj[,,2]),!is.na(obs[,,2])),add=TRUE,col=colours(1)[3*i+272],normalize=TRUE,pcex=3,pch="^")
  taylor.diagram(subset(as.vector(obs[,,3]),!is.na(obs[,,3])),subset(as.vector(adj[,,3]),!is.na(obs[,,3])),add=TRUE,col=colours(1)[3*i+272],normalize=TRUE,pcex=3,pch="~")
  taylor.diagram(subset(as.vector(obs[,,4]),!is.na(obs[,,4])),subset(as.vector(adj[,,4]),!is.na(obs[,,4])),add=TRUE,col=colours(1)[3*i+272],normalize=TRUE,pcex=2,pch="v")
  
  nameparts <- strsplit(bc_files,"_")[[i]]
  legendstrings[i] <- paste(nameparts[4],nameparts[5],nameparts[6],nameparts[7],sep="_")
}

text(0.5,0.03,"Centered root mean square difference",col="grey")

legend(x=1.8,1.7,legend=legendstrings,col=colours(1)[seq(275,320,3)],pch=16,bty="n")
legend(x=1.8,0.6,legend=c("Winter  ","Spring  ","Summer    ","Fall"),col="lightskyblue4",pch=c("*","^","~","v"),bty="n",horiz = TRUE)
legend(x=1.8,0.5,legend=c("(small symbols) Raw","(big symbols) Bias-corrected"),col="lightskyblue4",pch=c("v","V"),bty="n",horiz = TRUE)


dev.off()
